# encoding: utf-8

"""
opcvm_sdk.test.test_history

@author:        Eric Pieuchot
@copyright:     Copyright 2016 Rubicubix Ltd
@license:       Apache-2.0
@contact:       contact@rubicubix.co.uk
"""

from unittest import (
    main as testMain,
    TestCase,
)

from opcvm_sdk.services import OpcvmService
from opcvm_sdk.config import Config

from pandas import DataFrame


class TestHistory(TestCase):
    """History unit tests"""

    def setUp(self):
        self.service = OpcvmService()
        self.config = Config()
        self.isin = 'LU0068578508'
        self.id = 2373

    def tearDown(self):
        del self.service
        del self.config

    def test_history_by_id(self):
        """Test case for get_history_by_id"""
        _fundshare = self.service.get_fundshare_by_id(self.id)
        _sample = {
            _fundshare.lastVlDate: _fundshare.lastVl
        }
        _history = self.service.get_history_by_id(
            self.id,
            _fundshare.lastVlDate.strftime(self.config.format),
            _fundshare.lastVlDate.strftime(self.config.format)
        )
        self.assertIsInstance(_history, DataFrame)
        self.assertDictEqual(_history['vl'].to_dict(), _sample)
        del _fundshare
        del _history
        del _sample

    def test_history_by_isin(self):
        """Test case for get_history_by_isin"""
        _fundshare = self.service.get_fundshare_by_isin(self.isin)
        _sample = {
            _fundshare.lastVlDate: _fundshare.lastVl
        }
        _history = self.service.get_history_by_isin(
            self.isin,
            _fundshare.lastVlDate.strftime(self.config.format),
            _fundshare.lastVlDate.strftime(self.config.format)
        )
        self.assertIsInstance(_history, DataFrame)
        self.assertDictEqual(_history['vl'].to_dict(), _sample)
        del _fundshare
        del _history
        del _sample


if __name__ == '__main__':
    testMain()
